com.github.dnikku.clojure-testing.repl-testing


*test-var-extra*clj


-run-testsclj


reportcljmultimethod


run-testsclj

(run-tests pattern)
(run-tests pattern exclude-re)

Run c.t.n.r.refresh for loading all changed files namespaces and all deps, then run all tests matching pattern.

Run c.t.n.r.refresh for loading all changed files namespaces and all deps,
then run all tests matching pattern.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries